aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries
diff options
context:
space:
mode:
authorpmikus <pmikus@cisco.com>2021-12-22 12:38:26 +0100
committerPeter Mikus <pmikus@cisco.com>2021-12-22 12:21:42 +0000
commita9a0e77809de43d3981bcceca1e5eafdc4e32b74 (patch)
tree0f27f3281541723474a6aa30910819967130aff2 /resources/libraries
parenta93f42dff3a1a1d5073c36455cda0537eac5bb12 (diff)
fix(uti): Fixing broken code part II
Part of fixing chain after early merge. Signed-off-by: pmikus <pmikus@cisco.com> Change-Id: I983b3036a388656bbad91aba71cf14b503f875bd
Diffstat (limited to 'resources/libraries')
-rw-r--r--resources/libraries/bash/function/common.sh73
-rw-r--r--resources/libraries/bash/function/per_patch.sh2
2 files changed, 41 insertions, 34 deletions
diff --git a/resources/libraries/bash/function/per_patch.sh b/resources/libraries/bash/function/per_patch.sh
index b6a572d654..d48295d06e 100644
--- a/resources/libraries/bash/function/per_patch.sh
+++ b/resources/libraries/bash/function/per_patch.sh
@@ -38,7 +38,7 @@ function archive_test_results () {
TARGET="$(readlink -f "$1")"
mkdir -p "${TARGET}" || die "Directory creation failed."
file_list=("output.xml" "log.html" "report.html")
- file_list+=("tests" "tests_output_raw.tar.xz")
+ file_list+=("tests" "tests_output_raw.tar.gz")
for filename in "${file_list[@]}"; do
mv "${ARCHIVE_DIR}/${filename}" "${TARGET}/${filename}" || {
die "Attempt to move '${filename}' failed."
diff --git a/resources/libraries/bash/function/common.sh b/resources/libraries/bash/function/common.sh
index 86e2ace2fb..49b60ad118 100644
--- a/resources/libraries/bash/function/common.sh
+++ b/resources/libraries/bash/function/common.sh
@@ -602,6 +602,42 @@ function move_archives () {
}
+function post_process_robot_outputs () {
+
+ # Generate INFO level output_info.xml by rebot.
+ # Archive UTI raw json outputs.
+ #
+ # Variables read:
+ # - ARCHIVE_DIR - Path to post-processed files.
+
+ set -exuo pipefail
+
+ # Compress raw json outputs, as they will never be post-processed.
+ pushd "${ARCHIVE_DIR}" || die
+ if [ -d "tests" ]; then
+ # Use deterministic order.
+ options+=("--sort=name")
+ # We are keeping info outputs where they are.
+ # Assuming we want to move anything but info files (and dirs).
+ options+=("--exclude=*.info.json")
+ tar czvf "tests_output_raw.tar.gz" "${options[@]}" "tests" || true
+ # Tar can remove when archiving, but chokes (not deterministically)
+ # on attempting to remove dirs (not empty as info files are there).
+ # So we need to delete the raw files manually.
+ find "tests" -type f -name "*.raw.json" -delete || true
+ fi
+ popd || die
+
+ # Generate INFO level output_info.xml for post-processing.
+ all_options=("--loglevel" "INFO")
+ all_options+=("--log" "none")
+ all_options+=("--report" "none")
+ all_options+=("--output" "${ARCHIVE_DIR}/output_info.xml")
+ all_options+=("${ARCHIVE_DIR}/output.xml")
+ rebot "${all_options[@]}" || true
+}
+
+
function prepare_topology () {
# Prepare virtual testbed topology if needed based on flavor.
@@ -712,9 +748,9 @@ function reserve_and_cleanup_testbed () {
function run_pybot () {
# Run pybot with options based on input variables. Create output_info.xml
#
# Also, .info.json files are moved into an archive to speed up PAL.
#
# Variables read:
# - CSIT_DIR - Path to existing root of local CSIT git repository.
@@ -738,37 +774,8 @@ function run_pybot () {
PYBOT_EXIT_STATUS="$?"
set -e
- # Compress raw json outputs, if any.
- pushd "${ARCHIVE_DIR}" || die
- if [ -d "tests" ]; then
- # Use deterministic order.
- options+=("--sort=name")
- # We are keeping info outputs where they are.
- # Assuming we want to move anything but info files (and dirs).
- options+=("--exclude=*.info.json")
- # There may be other unforeseen errors,
- # we still want to execute subsequent commands, so disable set -e.
- set +e
- tar cvf "tests_output_raw.tar" "${options[@]}" "tests"
- # If compression fails, it leaves an uncompressed .tar,
- # we still want to archive that to investigate why compression failed.
- time xz -9e "tests_output_raw.tar"
- # Tar can remove when archiving, but chokes (not deterministically)
- # on attempting to remove dirs (not empty as info files are there).
- # So we need to delete the raw files manually.
- find "tests" -type f -name "*.raw.json" -delete
- set -e
- fi
- popd || die
+ post_process_robot_outputs || die
- # Generate INFO level output_info.xml for post-processing.
- # This comes last, as it is slowest, and sometimes users abort here.
- all_options=("--loglevel" "INFO")
- all_options+=("--log" "none")
- all_options+=("--report" "none")
- all_options+=("--output" "${ARCHIVE_DIR}/output_info.xml")
- all_options+=("${ARCHIVE_DIR}/output.xml")
- rebot "${all_options[@]}" || true
popd || die "Change directory operation failed."
}
@@ -712,9 +748,9 @@ function reserve_and_cleanup_testbed () {
function run_pybot () {
- # Run pybot with options based on input variables. Create output_info.xml
- #
- # Also, .info.json files are moved into an archive to speed up PAL.
+ # Run pybot with options based on input variables.
+ # Generate INFO level output_info.xml by rebot.
+ # Archive UTI raw json outputs.
#
# Variables read: